@@ -2,7 +2,7 @@ import os
 
 
 class EnterDir:
-    def __init__(self, go_to: str, create=False):
+    def __init__(self, go_to: str, create: bool = False):
         self.back_to: str = os.getcwd()
         self.go_to: str = go_to
         self.create: bool = create
